*******************************************************************	
* Do file for Prorok "The (In)Compatibility of Peace and Justice?"

*** this file replicates all tables and figures from the main text	
*******************************************************************	

clear
use Prorok_IO_replication.dta	


************************************************
* Table 1
************************************************
* Model 1	
logit terminate_nm iccactive_cntrylevel icc_ratif lnnumofdyads mixedreg lnpop balancedinterv_all  terrcont2_nm parity_nm rebpolwinglegal2_nm africa count count2 count3 , cluster(dyadid)	

* Model 2	
logit terminate_nm iccactive_cntrylevel##c.lncivfatdiff_y  icc_ratif lnnumofdyads mixedreg lnpop balancedinterv_all  terrcont2_nm parity_nm rebpolwinglegal2_nm africa count count2 count3 , cluster(dyadid)	


************************************************
* Figure 1
************************************************
qui logit terminate_nm iccactive_cntrylevel icc_ratif lnnumofdyads mixedreg lnpop balancedinterv_all  terrcont2_nm parity_nm rebpolwinglegal2_nm africa count count2 count3 , cluster(dyadid)	
qui margins, at(iccactive_cntrylevel=(0 1)) vsquish
marginsplot, recast(bar) recastci(rcap) ///
  ciopts(lw(medthick) color(black)) ///
  plotopts(barw(.5) color(gs10)) ///
  xmtick(-.5(.5)1.5) ///
  ytitle(Predicted Probability of Termination) ///
  title("Figure 1: Predicted Probability of Termination, Model 1", size(medlarge)) ///
  graphregion(color(white)) ///
  note("Note: 95% Confidence Intervals reported.", size(small)) 


************************************************
* Figure 2
************************************************
qui logit terminate_nm iccactive_cntrylevel##c.lncivfatdiff_y  icc_ratif lnnumofdyads mixedreg lnpop balancedinterv_all  terrcont2_nm parity_nm rebpolwinglegal2_nm africa count count2 count3 , cluster(dyadid)	
qui margins, at(lncivfatdiff_y=(0(1)8) iccactive_cntrylevel=(0 1)) vsquish
marginsplot, recast(line) recastci(rarea) yline(0) ///
  ci1opts(color(gs12)) ///
  ci2opts(color(gs8)) ///
  plot1opts(lw(medthick) lcolor(gs3)) ///
  plot2opts(lw(medthick) lcolor(gs1) lpattern(dash)) ///
  ytitle(Predicted Probability of Termination) ///
  legend(size(small) order(3 "No ICC" 4 "ICC Involvement")) ///
  xtitle(Disparity in Civilians Killed (ln)) ///
  title(A. Predicted Probability of Termination, size(medlarge)) ///
  subtitle(by ICC Involvement and Civilian Fatalities Disparity, size(medsmall)) ///
  graphregion(color(white)) ///
  saving (m2_ppgraph.gph, replace)
qui margins, dydx(iccactive_cntrylevel) at(lncivfatdiff_y=(0(1)8)) vsquish	
marginsplot, recast(line) recastci(rarea) yline(0) ///
  ciopts(color(gs8)) ///
  plotopts(lw(medthick) lcolor(gs1) lpattern(dash)) ///
  addplot(pci 0 0 0 8, lcolor(cranberry)) ///
  ytitle(Change in Probability of Termination) ///
  xtitle(Disparity in Civilians Killed (ln)) ///
  title(B. Change in Predicted Probability, size(medlarge)) ///
  subtitle(Baseline: No Active ICC Involvement, size(medsmall)) ///
  legend(off) ///
  graphregion(color(white)) ///
  saving (m2_fdgraph.gph, replace)
#delimit;
graph combine m2_ppgraph.gph m2_fdgraph.gph ,
  col(2)
  title("Figure 2: Predicted Probability of Termination, Model 2", size(medlarge))
  subtitle("", size(medsmall))
  graphregion(color(white))
  note("Note: 95% Confidence Intervals reported.", size(small)) 
  ;
#delimit cr


***************************************************
* Table 2
***************************************************	
* Model 1	
ivprobit terminate_nm icc_ratif lnnumofdyads mixedreg lnpop balancedinterv_all terrcont2_nm parity_nm rebpolwinglegal2_nm africa c_cwars ethwartek12 lnldrtenure_yrend count count2 count3 (iccactive_cntrylevel= p5_ipddumc25avg c_ipddumc25avg c_numratifierslag), cluster(dyadid)	
	
* Model 2
qui reg iccactive_cntrylevel p5_ipddumc25avg c_ipddumc25avg c_numratifierslag lncivfatdiff_y icc_ratif lnnumofdyads mixedreg lnpop balancedinterv_all  terrcont2_nm parity_nm africa rebpolwinglegal2_nm c_cwars ethwartek12 lnldrtenure_yrend count count2 count3 , cluster(dyadid)	
predict xb2a, xb	
gen xb2axlncivfatdiff=xb2a*lncivfatdiff_y	
qui regress iccactiveclxlncivfatdiff xb2axlncivfatdiff lncivfatdiff_y icc_ratif lnnumofdyads mixedreg lnpop balancedinterv_all  terrcont2_nm parity_nm africa rebpolwinglegal2_nm c_cwars ethwartek12 lnldrtenure_yrend count count2 count3 , cluster(dyadid)	
predict xb2b, xb	
logit terminate_nm xb2a lncivfatdiff_y xb2b icc_ratif lnnumofdyads mixedreg lnpop balancedinterv_all  terrcont2_nm parity_nm africa rebpolwinglegal2_nm c_cwars ethwartek12 lnldrtenure_yrend count count2 count3, vce(bootstrap, rep(100) seed(2) cluster(dyadid) idcluster(newid) group(dyadid))	



***************************************************
* Figure 3
***************************************************

qui estsimp logit terminate_nm xb2a lncivfatdiff_y xb2b icc_ratif lnnumofdyads mixedreg lnpop balancedinterv_all  terrcont2_nm parity_nm africa rebpolwinglegal2_nm c_cwars ethwartek12 lnldrtenure_yrend count count2 count3, vce(bootstrap, rep(100) seed(2) cluster(dyadid) idcluster(newid) group(dyadid)) genname(m2) sims(10000)	
setx xb2a .24 lncivfatdiff_y 0 xb2b 0 icc_ratif 0 lnnumofdyads mean mixedreg 1 lnpop mean balancedinterv_all 0 terrcont2_nm 0 parity_nm 0 africa 0 rebpolwinglegal2_nm 0 c_cwars mean ethwartek12 1 lnldrtenure_yrend mean count 10.043 count2 100.862 count3 1012.956	
simqi, fd(pr) changex(xb2a -.29 1.15 lncivfatdiff_y 0 0 xb2b 0 0) 	
simqi, fd(pr) changex(xb2a -.29 1.15 lncivfatdiff_y 1 1 xb2b -.29 1.15) 	
simqi, fd(pr) changex(xb2a -.29 1.15 lncivfatdiff_y 2 2 xb2b -.58 2.3) 	
simqi, fd(pr) changex(xb2a -.29 1.15 lncivfatdiff_y 3 3 xb2b -.87 3.45) 	
simqi, fd(pr) changex(xb2a -.29 1.15 lncivfatdiff_y 4 4 xb2b -1.16 4.6) 	
simqi, fd(pr) changex(xb2a -.29 1.15 lncivfatdiff_y 5 5 xb2b -1.45 5.75) 	
simqi, fd(pr) changex(xb2a -.29 1.15 lncivfatdiff_y 6 6 xb2b -1.74 6.9) 	
simqi, fd(pr) changex(xb2a -.29 1.15 lncivfatdiff_y 7 7 xb2b -2.03 8.05) 	
simqi, fd(pr) changex(xb2a -.29 1.15 lncivfatdiff_y 8 8 xb2b -2.32 9.2) 	

clear
insheet using postest_figures.csv	
gen axis=0
* fd graph
#delimit;
twoway (rarea min95 max95 civfatdiff_y if civfatdiff_y<9 & figure==3, color(gs10)) 
  (line fd civfatdiff_y if civfatdiff_y<9 & figure==3, lcolor(black) lw(medthick))
  (line axis civfatdiff_y if civfatdiff_y<9 & figure==3, lcolor(cranberry) lw(med)),
  title("Figure 3: Change in Predicted Probability of Termination", size(medlarge))
  subtitle("2SLS Model 2", size(med))
  xtitle("Disparity in Civilians Killed (ln)")
  ytitle("Change in Probability of Termination")			
  xlabel(0(1)8)
  ylabel(-.4(.1)0)
  ymtick(-.35(.05).05)
  legend(off)
  yline(0, lstyle(foreground) lcolor(cranberry) lw(med))
  graphregion(color(white))
  note(" " "Note: 95% Confidence Intervals reported." "Reports change in pr(termination) moving ICC fitted values from min to max.", size(small)) 
  ;
#delimit cr	






